# **PyJS**
Ever wanted to use JS functions in Python? Now you can! PyJS provides you with a lot of functions from JavaScript. The library is still being worked on, and any contributions are welcome.

## **Installation**
Use `python -m pip install Python.js`

## **Example**
```py
from PyJS import * # you may want to do this so you don't have to add PyJS. in front of every function.

string = "I wonder how many characters this string is..."

console.log(f"\"{string}\" is {string.length} characters long!")
```
*And much more!*

## **Documentation**
Coming soon...!